==> fd-faq-900.0-noarch-1.txz: usr/share/doc/fd-faq/flash_player.md <==
%%textdomain fatdoghelp

 
![Fatdog64 logo](img/fatdog64-header.png)

#  
# Fatdog64-900 does not include the Flash Player
#  

(It is still in the package repository.)

**(Q)** When I access my webmail I notice the Seamonkey is complaining about Flash8 or later is not installed. How come?

You did not see that error message in Fatdog64-814 because the version of Seamonkey in Fatdog64 814 (and older) supported Flash, and the Flash plugin was included in the ISO. Neither is true in Fatdog64-900.

If you really want Flash, install Palemoon and the Flash plugin from the repository, and access your webmail using Palemoon.

Adobe terminated Flash update and support by end of 2020. Then web browsers themselves started to drop support for NPAPI plugins, the plugins that Flash depends on, which means that even if you have the Adobe Flash plugin installed, it won't work.

Firefox dropped support for NPAPI plugins many versions ago, and Chrome has never supported NPAPI in the first place (but they had their own Flash player, which they have also dropped many versions ago).

A browser that we know still supports Flash (and hence works with Flash) is Palemoon. It is for this reason we still keep a copy of the final version of the flash player in the Fatdog64-900 Gslapt repository.

Go visit [http:`//embed-swf.org/flash-player-version.php`](http://embed-swf.org/flash-player-version.php) to check if your browser supports Flash.

------------------------------------------------------------------------

The bottom line is the Flash player is outdated and not supported by most browsers anymore.

----

[Fatdog64](home.md)
| [FAQ index](faq.md)
| [FAQ files](faq_file_list.md)
| [Fatdog64 online](https://distro.ibiblio.org/fatdog/web)
| [FAQ online](https://distro.ibiblio.org/fatdog/web/faqs/faq.html)

----

_This page was automatically converted from [flash\_player.html](https://distro.ibiblio.org/fatdog/web/faqs/flash\_player.html) on 2023-09-08._

==> fd-faq-901.0-noarch-1.txz: usr/share/doc/fd-faq/flash_player.md <==
%%textdomain fatdoghelp

 
![Fatdog64 logo](img/fatdog64-header.png)

#  
# Fatdog64-900 does not include the Flash Player
#  

(It is still in the package repository.)

**(Q)** When I access my webmail I notice the Seamonkey is complaining about Flash8 or later is not installed. How come?

You did not see that error message in Fatdog64-814 because the version of Seamonkey in Fatdog64 814 (and older) supported Flash, and the Flash plugin was included in the ISO. Neither is true in Fatdog64-900.

If you really want Flash, install Palemoon and the Flash plugin from the repository, and access your webmail using Palemoon.

Adobe terminated Flash update and support by end of 2020. Then web browsers themselves started to drop support for NPAPI plugins, the plugins that Flash depends on, which means that even if you have the Adobe Flash plugin installed, it won't work.

Firefox dropped support for NPAPI plugins many versions ago, and Chrome has never supported NPAPI in the first place (but they had their own Flash player, which they have also dropped many versions ago).

A browser that we know still supports Flash (and hence works with Flash) is Palemoon. It is for this reason we still keep a copy of the final version of the flash player in the Fatdog64-900 Gslapt repository.

Go visit <http://embed-swf.org/flash-player-version.php> to check if your browser supports Flash.

------------------------------------------------------------------------

The bottom line is the Flash player is outdated and not supported by most browsers anymore.

----

[Fatdog64](home.md)
| [FAQ index](faq.md)
| [FAQ files](faq_file_list.md)
| [Fatdog64 online](https://distro.ibiblio.org/fatdog/web)
| [FAQ online](https://distro.ibiblio.org/fatdog/web/faqs/faq.html)

----

_This page was automatically converted from [flash\_player.html](https://distro.ibiblio.org/fatdog/web/faqs/flash\_player.html) on 2023-10-09._
